﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace CoreLibrary.Events
{
    /// <summary>
    /// Représente les arguments d'événement pour la fin d'une partie.
    /// </summary>
    public class PartieTermineeEventArgs : EventArgs
    {
        /// <summary>
        /// Obtient les joueurs gagnants de la partie.
        /// </summary>
        public IEnumerable<Joueur> Gagnants { get; private set; }

        /// <summary>
        /// Obtient les joueurs perdants de la partie.
        /// </summary>
        public IEnumerable<Joueur> Perdants { get; private set; }

        /// <summary>
        /// Initialise une nouvelle instance de la classe <see cref="PartieTermineeEventArgs"/> avec les gagnants et les perdants spécifiés.
        /// </summary>
        /// <param name="gagnants">Les joueurs gagnants de la partie.</param>
        /// <param name="perdants">Les joueurs perdants de la partie.</param>
        public PartieTermineeEventArgs(IEnumerable<Joueur> gagnants, IEnumerable<Joueur> perdants)
        {
            Gagnants = gagnants;
            Perdants = perdants;
        }
    }
}
